@@ -1,4 +1,4 @@
-{-# LANGUAGE CPP, UnicodeSyntax, NoImplicitPrelude, FlexibleContexts #-}
+{-# LANGUAGE CPP, NoImplicitPrelude, FlexibleContexts #-}
 
 #if __GLASGOW_HASKELL__ >= 702
 {-# LANGUAGE Trustworthy #-}
@@ -22,15 +22,13 @@
 module System.Timeout.Lifted ( timeout ) where
 
 -- from base:
+import Prelude                       ( (.) )
 import           Data.Int            ( Int )
 import           Data.Maybe          ( Maybe(Nothing, Just), maybe )
 import           Control.Monad       ( (>>=), return, liftM )
 import           System.IO           ( IO )
 import qualified System.Timeout as T ( timeout )
 
--- from base-unicode-symbols:
-import Data.Function.Unicode ( (∘) )
-
 -- from monad-control:
 import Control.Monad.Trans.Control ( MonadBaseControl, restoreM, liftBaseWith )
 
@@ -41,7 +39,7 @@ import Control.Monad.Trans.Control ( MonadBaseControl, restoreM, liftBaseWith )
 -- Note that when the given computation times out any side effects of @m@ are
 -- discarded. When the computation completes within the given time the
 -- side-effects are restored on return.
-timeout ∷ MonadBaseControl IO m ⇒ Int → m a → m (Maybe a)
-timeout t m = liftBaseWith (\runInIO → T.timeout t (runInIO m)) >>=
-                maybe (return Nothing) (liftM Just ∘ restoreM)
+timeout :: MonadBaseControl IO m => Int -> m a -> m (Maybe a)
+timeout t m = liftBaseWith (\runInIO -> T.timeout t (runInIO m)) >>=
+                maybe (return Nothing) (liftM Just . restoreM)
 {-# INLINABLE timeout #-}
